@@ -26,7 +26,7 @@
 #' [Microsoft Teams API reference](https://learn.microsoft.com/en-us/graph/api/resources/teams-api-overview?view=graph-rest-1.0)
 #' @format An R6 object of class `ms_team_member`, inheriting from `ms_object`.
 #' @export
-ms_team_member <- R6::R6Class("ms_team_member", inherit=ms_object,
+ms_team_member <- R6::R6Class("ms_team_member", inherit=ms_teams_object,
 
 public=list(
 
